@@ -14,8 +14,8 @@ def portsniffer(log_file):
         print 'Could not open log file: %s' % log_file
         return None, None
 
-    current_port = None
-    current_ip = None
+    found_port = None
+    found_ip = None
     try:
         for l in fo.readlines():
             if 'bound to TCP address' in l:
@@ -24,11 +24,11 @@ def portsniffer(log_file):
                 before1, after1 = after0.split('(port')
                 before1 = before1.strip()
                 ip, port = before1.split(':')
-                current_ip = ip
-                current_port = port
+                found_ip = ip
+                found_port = port
         fo.close()
     except Exception, e:
         print 'Error scanning log file: %s' % log_file
         print e
         return None, None
-    return current_ip, current_port
+    return found_ip, found_port
